@@ -113,6 +113,7 @@ class AlbumArtist(DataObject):
 
 class Album(DataObject, Item):
 
+    metadata_images_changed = QtCore.pyqtSignal()
     release_group_loaded = QtCore.pyqtSignal()
 
     def __init__(self, album_id, discid=None):
@@ -131,7 +132,7 @@ class Album(DataObject, Item):
             self._discids.add(discid)
         self._after_load_callbacks = []
         self.unmatched_files = Cluster(_("Unmatched Files"), special=True, related_album=self, hide_if_empty=True)
-        self.errors = []
+        self.unmatched_files.metadata_images_changed.connect(self.update_metadata_images)
         self.status = None
         self._album_artists = []
         self.update_metadata_images_enabled = True
@@ -141,11 +142,9 @@ class Album(DataObject, Item):
 
     def iterfiles(self, save=False):
         for track in self.tracks:
-            for file in track.iterfiles():
-                yield file
+            yield from track.iterfiles()
         if not save:
-            for file in self.unmatched_files.iterfiles():
-                yield file
+            yield from self.unmatched_files.iterfiles()
 
     def enable_update_metadata_images(self, enabled):
         self.update_metadata_images_enabled = enabled
@@ -167,7 +166,7 @@ class Album(DataObject, Item):
             if track_discids:
                 track.metadata['musicbrainz_discid'] = track_discids
                 track.update()
-                for file in track.linked_files:
+                for file in track.files:
                     file.metadata['musicbrainz_discid'] = track_discids
                     file.update()
 
@@ -283,10 +282,6 @@ class Album(DataObject, Item):
         #     Do not directly delete it inside the slot connected to finished().
         #     You can use the deleteLater() function.
 
-    def error_append(self, msg):
-        log.error(msg)
-        self.errors.append(msg)
-
     def _finalize_loading(self, error):
         if error:
             self.metadata.clear()
@@ -371,16 +366,18 @@ class Album(DataObject, Item):
 
             for track in self._new_tracks:
                 track.metadata["~totalalbumtracks"] = totalalbumtracks
-                track.orig_metadata["~totalalbumtracks"] = totalalbumtracks
                 if len(artists) > 1:
                     track.metadata["~multiartist"] = "1"
-                    track.orig_metadata["~multiartist"] = "1"
             del self._release_node
             del self._release_artist_nodes
             self._tracks_loaded = True
 
         if not self._requests:
             self.enable_update_metadata_images(False)
+            for track in self._new_tracks:
+                track.orig_metadata.copy(track.metadata)
+                track.metadata_images_changed.connect(self.update_metadata_images)
+
             # Prepare parser for user's script
             for s_name, s_text in enabled_tagger_scripts_texts():
                 parser = ScriptParser()
@@ -399,18 +396,16 @@ class Album(DataObject, Item):
                     log.exception("Failed to run tagger script %s on album", s_name)
                 self._new_metadata.strip_whitespace()
 
-            for track in self.tracks:
-                track.metadata_images_changed.connect(self.update_metadata_images)
-                for file in list(track.linked_files):
-                    file.move(self.unmatched_files)
+            unmatched_files = [file for track in self.tracks for file in track.files]
             self.metadata = self._new_metadata
             self.orig_metadata.copy(self.metadata)
+            self.orig_metadata.images.clear()
             self.tracks = self._new_tracks
             del self._new_metadata
             del self._new_tracks
             self.loaded = True
             self.status = None
-            self.match_files(self.unmatched_files.files)
+            self.match_files(unmatched_files + self.unmatched_files.files)
             self.enable_update_metadata_images(True)
             self.update()
             self.tagger.window.set_statusbar_message(
@@ -458,7 +453,6 @@ class Album(DataObject, Item):
         except BaseException:
             self.error_append(traceback.format_exc())
 
-        track.orig_metadata.copy(tm)
         return track
 
     def load(self, priority=False, refresh=False):
@@ -476,11 +470,11 @@ class Album(DataObject, Item):
             self.release_group.genres.clear()
         self.metadata.clear()
         self.genres.clear()
-        self.update()
+        self.update(update_selection=False)
         self._new_metadata = Metadata()
         self._new_tracks = []
         self._requests = 1
-        self.errors = []
+        self.clear_errors()
         require_authentication = False
         inc = ['release-groups', 'media', 'discids', 'recordings', 'artist-credits',
                'artists', 'aliases', 'labels', 'isrcs', 'collections']
@@ -510,23 +504,23 @@ class Album(DataObject, Item):
             self.tagger.webservice.remove_task(self.load_task)
             self.load_task = None
 
-    def update(self, update_tracks=True):
+    def update(self, update_tracks=True, update_selection=True):
         if self.item:
-            self.item.update(update_tracks)
+            self.item.update(update_tracks, update_selection=update_selection)
 
-    def _add_file(self, track, file):
+    def _add_file(self, track, file, new_album=True):
         self._files += 1
-        self.update(update_tracks=False)
-        add_metadata_images(self, [file])
-        file.metadata_images_changed.connect(self.update_metadata_images)
+        if new_album:
+            self.update(update_tracks=False)
+            add_metadata_images(self, [file])
 
-    def _remove_file(self, track, file):
+    def _remove_file(self, track, file, new_album=True):
         self._files -= 1
-        self.update(update_tracks=False)
-        file.metadata_images_changed.disconnect(self.update_metadata_images)
-        remove_metadata_images(self, [file])
+        if new_album:
+            self.update(update_tracks=False)
+            remove_metadata_images(self, [file])
 
-    def _match_files(self, files, recordingid=None, threshold=0):
+    def _match_files(self, files, threshold=0):
         """Match files to tracks on this album, based on metadata similarity or recordingid."""
         tracks_cache = defaultdict(lambda: None)
 
@@ -547,7 +541,7 @@ class Album(DataObject, Item):
             if file.state == File.REMOVED:
                 continue
             # if we have a recordingid to match against, use that in priority
-            recid = recordingid or file.metadata['musicbrainz_recordingid']
+            recid = file.match_recordingid or file.metadata['musicbrainz_recordingid']
             if recid and mbid_validate(recid):
                 if not tracks_cache:
                     build_tracks_cache()
@@ -576,13 +570,15 @@ class Album(DataObject, Item):
             else:
                 yield (file, best_match.result.track)
 
-    def match_files(self, files, recordingid=None):
+    def match_files(self, files):
         """Match and move files to tracks on this album, based on metadata similarity or recordingid."""
-        moves = self._match_files(files,
-                                  recordingid=recordingid,
-                                  threshold=config.setting['track_matching_threshold'])
-        for file, target in moves:
-            file.move(target)
+        if self.loaded:
+            moves = self._match_files(files, threshold=config.setting['track_matching_threshold'])
+            for file, target in moves:
+                file.move(target)
+        else:
+            for file in list(files):
+                file.move(self.unmatched_files)
 
     def can_save(self):
         return self._files > 0
@@ -635,7 +631,7 @@ class Album(DataObject, Item):
     def is_modified(self):
         if self.tracks:
             for track in self.tracks:
-                for file in track.linked_files:
+                for file in track.files:
                     if not file.is_saved():
                         return True
         return False
@@ -643,7 +639,7 @@ class Album(DataObject, Item):
     def get_num_unsaved_files(self):
         count = 0
         for track in self.tracks:
-            for file in track.linked_files:
+            for file in track.files:
                 if not file.is_saved():
                     count += 1
         return count
@@ -721,9 +717,9 @@ class Album(DataObject, Item):
         if not self.update_metadata_images_enabled:
             return
 
-        update_metadata_images(self)
-
-        self.update(False)
+        if update_metadata_images(self):
+            self.update(False)
+            self.metadata_images_changed.emit()
 
     def keep_original_images(self):
         self.enable_update_metadata_images(False)
@@ -749,7 +745,7 @@ class NatAlbum(Album):
         for track in self.tracks:
             if old_album_title == track.metadata["album"]:
                 track.metadata["album"] = self.metadata["album"]
-            for file in track.linked_files:
+            for file in track.files:
                 track.update_file_metadata(file)
         self.enable_update_metadata_images(True)
         super().update(update_tracks)
